@@ -1,249 +1,205 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="sl" version="2.1">
 <context>
-    <name>QApplication</name>
+    <name>MainWindow</name>
     <message>
-        <location filename="main.cpp" line="53"/>
-        <source>You must run this program as root.</source>
-        <translation>Ta program morate zagnati kot root</translation>
-    </message>
-</context>
-<context>
-    <name>bootrepair</name>
-    <message>
-        <location filename="bootrepair.ui" line="20"/>
-        <location filename="bootrepair.cpp" line="445"/>
-        <location filename="ui_bootrepair.h" line="389"/>
+        <location filename="mainwindow.ui" line="20"/>
         <source>Boot Repair</source>
         <translation>Popravilo zagona</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="39"/>
+        <location filename="mainwindow.ui" line="39"/>
         <source>Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
         <translation>Popravljanje zagona je orodje za ponovno namestitev GRUB zaganjalnika na ESP (EFI sistemski razdelek), MBR (Master Boot Record) ali root razdelek. Ponuja možnost rekonstrukcije GRUB konfiguracijske datoteke in ustvarjanja varnostne kopije MBR ali PBR (root) ali obnovo iz le-te.</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="58"/>
-        <location filename="ui_bootrepair.h" line="391"/>
+        <location filename="mainwindow.ui" line="58"/>
         <source>What would you like to do?</source>
         <translation>Kaj bi radi storili?</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="79"/>
-        <location filename="ui_bootrepair.h" line="392"/>
+        <location filename="mainwindow.ui" line="79"/>
         <source>Backup MBR or PBR (legacy boot only)</source>
         <translation>Varnostno kopiranje MBR ali PBR (samo za legacy zagon)</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="86"/>
+        <location filename="mainwindow.ui" line="86"/>
         <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
         <translation>Ponovno namesti GRUB zaganjalnik na ESP, MPR ali PBR (root)</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="96"/>
-        <location filename="ui_bootrepair.h" line="394"/>
+        <location filename="mainwindow.ui" line="96"/>
         <source>Repair GRUB configuration file</source>
         <translation>Popravi GRUB konfiguracijo</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="103"/>
-        <location filename="ui_bootrepair.h" line="395"/>
+        <location filename="mainwindow.ui" line="103"/>
         <source>Restore MBR or PBR from backup (legacy boot only)</source>
         <translation>Obnovi MBR ali PBR iz varnostne kopije (samo za legacy zagon)</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="123"/>
-        <location filename="bootrepair.cpp" line="378"/>
-        <location filename="ui_bootrepair.h" line="396"/>
+        <location filename="mainwindow.ui" line="136"/>
+        <location filename="mainwindow.cpp" line="485"/>
         <source>Select Boot Method</source>
         <translation>Določi zagonski način</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="141"/>
-        <location filename="ui_bootrepair.h" line="398"/>
+        <location filename="mainwindow.ui" line="154"/>
         <source>Master Boot Record</source>
         <translation>Master Boot Record</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="144"/>
-        <location filename="ui_bootrepair.h" line="400"/>
+        <location filename="mainwindow.ui" line="157"/>
         <source>MBR</source>
         <translation>MBR</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="147"/>
-        <location filename="bootrepair.ui" line="418"/>
-        <location filename="ui_bootrepair.h" line="401"/>
-        <location filename="ui_bootrepair.h" line="420"/>
+        <location filename="mainwindow.ui" line="160"/>
+        <location filename="mainwindow.ui" line="430"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="169"/>
-        <location filename="ui_bootrepair.h" line="403"/>
+        <location filename="mainwindow.ui" line="182"/>
         <source>Root (Partition Boot Record)</source>
         <translation>Root (Partition Boot Record)</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="172"/>
-        <location filename="bootrepair.cpp" line="380"/>
-        <location filename="ui_bootrepair.h" line="405"/>
+        <location filename="mainwindow.ui" line="185"/>
+        <location filename="mainwindow.cpp" line="488"/>
         <source>root</source>
         <translation>koren</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="223"/>
-        <location filename="bootrepair.cpp" line="379"/>
-        <location filename="ui_bootrepair.h" line="406"/>
+        <location filename="mainwindow.ui" line="236"/>
+        <location filename="mainwindow.cpp" line="487"/>
         <source>Install on:</source>
         <translation>Namesti na:</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="242"/>
-        <location filename="ui_bootrepair.h" line="407"/>
+        <location filename="mainwindow.ui" line="255"/>
+        <location filename="mainwindow.cpp" line="486"/>
         <source>Location:</source>
         <translation>Lokacija:</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="264"/>
-        <location filename="ui_bootrepair.h" line="411"/>
-        <source>Select /boot location:</source>
-        <translation>Izberi lokacijo za /boot:</translation>
+        <location filename="mainwindow.ui" line="277"/>
+        <location filename="mainwindow.cpp" line="496"/>
+        <source>Select root location:</source>
+        <translation>Izberite lokacijo za root:</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="277"/>
-        <location filename="ui_bootrepair.h" line="413"/>
+        <location filename="mainwindow.ui" line="290"/>
         <source>EFI System Partition</source>
         <translation>EFI sistemski razdelek</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="280"/>
-        <location filename="ui_bootrepair.h" line="415"/>
+        <location filename="mainwindow.ui" line="293"/>
         <source>ESP</source>
         <translation>ESP</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="407"/>
-        <location filename="ui_bootrepair.h" line="417"/>
+        <location filename="mainwindow.ui" line="420"/>
         <source>About this application</source>
         <translation>O tem programu</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="410"/>
-        <location filename="ui_bootrepair.h" line="419"/>
+        <location filename="mainwindow.ui" line="423"/>
         <source>About...</source>
         <translation>O programu...</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="460"/>
-        <location filename="ui_bootrepair.h" line="422"/>
+        <location filename="mainwindow.ui" line="472"/>
         <source>Display help </source>
         <translation>Prikaži pomoč</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="463"/>
-        <location filename="ui_bootrepair.h" line="424"/>
+        <location filename="mainwindow.ui" line="475"/>
         <source>Help</source>
         <translation>Pomoč</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="471"/>
-        <location filename="ui_bootrepair.h" line="425"/>
+        <location filename="mainwindow.ui" line="482"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="512"/>
-        <location filename="ui_bootrepair.h" line="428"/>
+        <location filename="mainwindow.ui" line="523"/>
         <source>Cancel any changes then quit</source>
         <translation>Zavrzi vse spremembe in končaj</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="515"/>
-        <location filename="bootrepair.cpp" line="450"/>
-        <location filename="ui_bootrepair.h" line="430"/>
+        <location filename="mainwindow.ui" line="526"/>
         <source>Cancel</source>
-        <translation>Prekini</translation>
+        <translation>Prekliči</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="523"/>
-        <location filename="ui_bootrepair.h" line="431"/>
+        <location filename="mainwindow.ui" line="533"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="542"/>
-        <location filename="ui_bootrepair.h" line="433"/>
+        <location filename="mainwindow.ui" line="552"/>
         <source>Apply any changes</source>
         <translation>Potrdi vse spremembe</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="545"/>
-        <location filename="bootrepair.cpp" line="78"/>
-        <location filename="ui_bootrepair.h" line="435"/>
+        <location filename="mainwindow.ui" line="555"/>
+        <location filename="mainwindow.cpp" line="70"/>
         <source>Apply</source>
         <translation>Potrdi</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="96"/>
+        <location filename="mainwindow.cpp" line="86"/>
         <source>GRUB is being installed on %1 device.</source>
         <translation>GRUB se namešča na napravo %1</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="111"/>
-        <location filename="bootrepair.cpp" line="134"/>
-        <location filename="bootrepair.cpp" line="164"/>
-        <location filename="bootrepair.cpp" line="266"/>
-        <location filename="bootrepair.cpp" line="300"/>
-        <location filename="bootrepair.cpp" line="418"/>
-        <location filename="bootrepair.cpp" line="425"/>
+        <location filename="mainwindow.cpp" line="118"/>
+        <location filename="mainwindow.cpp" line="203"/>
+        <location filename="mainwindow.cpp" line="312"/>
+        <location filename="mainwindow.cpp" line="394"/>
+        <location filename="mainwindow.cpp" line="419"/>
+        <location filename="mainwindow.cpp" line="527"/>
+        <location filename="mainwindow.cpp" line="534"/>
+        <location filename="mainwindow.cpp" line="597"/>
         <source>Error</source>
         <translation>Napaka</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="112"/>
-        <source>Could not mount </source>
-        <translation>Priklop ni uspel</translation>
-    </message>
-    <message>
-        <location filename="bootrepair.cpp" line="112"/>
-        <source> on /boot/efi</source>
-        <translation>na /boot/efi</translation>
-    </message>
-    <message>
-        <location filename="bootrepair.cpp" line="135"/>
-        <location filename="bootrepair.cpp" line="165"/>
+        <location filename="mainwindow.cpp" line="119"/>
+        <location filename="mainwindow.cpp" line="204"/>
         <source>Could not set up chroot environment.
 Please double-check the selected location.</source>
         <translation>Ustvarjanje chroot okolja ni uspelo.
 Prosimo, da še enkrat preverite izbrano lokacijo.</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="152"/>
+        <location filename="mainwindow.cpp" line="179"/>
         <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
         <translation>Konfiguracijska datoteka za GRUB (grub.cfg) se ponovno gradi.</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="186"/>
+        <location filename="mainwindow.cpp" line="222"/>
         <source>Backing up MBR or PBR from %1 device.</source>
         <translation>Varnostno kopiranje MBR ali PBR iz naprave %1.</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="241"/>
+        <location filename="mainwindow.cpp" line="287"/>
         <source>Warning</source>
         <translation>Opozorilo</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="242"/>
+        <location filename="mainwindow.cpp" line="288"/>
         <source>You are going to write the content of </source>
         <translation>Zapisali boste vsebino iz </translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="242"/>
+        <location filename="mainwindow.cpp" line="288"/>
         <source> to </source>
         <translation>na</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="242"/>
+        <location filename="mainwindow.cpp" line="288"/>
         <source>
 
 Are you sure?</source>
@@ -252,122 +208,144 @@ Are you sure?</source>
 Ali ste prepričani?</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="243"/>
-        <location filename="bootrepair.cpp" line="296"/>
-        <source>Yes</source>
-        <translation>Da</translation>
-    </message>
-    <message>
-        <location filename="bootrepair.cpp" line="243"/>
-        <location filename="bootrepair.cpp" line="296"/>
-        <source>No</source>
-        <translation>Ne</translation>
-    </message>
-    <message>
-        <location filename="bootrepair.cpp" line="247"/>
+        <location filename="mainwindow.cpp" line="293"/>
         <source>Restoring MBR/PBR from backup to %1 device.</source>
         <translation>Obnova MBR/PBR iz varnostne kopije na napravo %1.</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="267"/>
+        <location filename="mainwindow.cpp" line="313"/>
         <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
         <translation>Nisem uspel najti EFI sistemskega razdelka (ESP) ali drug sistemski disk. Prosimo, ustvarite ESP in poskusite znova. </translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="294"/>
-        <source>Success</source>
-        <translation>Operacija je uspela</translation>
+        <location filename="mainwindow.cpp" line="348"/>
+        <source>Select %1 location:</source>
+        <translation>Izberite lokacijo %1:</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="295"/>
-        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit Boot Repair?&lt;/b&gt;</source>
-        <translation>Postopek je bil uspešno zaključen. &lt;p&gt;&lt;b&gt;Bi radi zaupstili Popravilo zagona?&lt;/b&gt;</translation>
-    </message>
-    <message>
-        <location filename="bootrepair.cpp" line="301"/>
-        <source>Process finished. Errors have occurred.</source>
-        <translation>Postopek je končan. Pojavile so se napake.</translation>
-    </message>
-    <message>
-        <location filename="bootrepair.cpp" line="303"/>
+        <location filename="mainwindow.cpp" line="372"/>
         <source>Back</source>
         <translation>Nazaj</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="387"/>
+        <location filename="mainwindow.cpp" line="388"/>
+        <source>Success</source>
+        <translation>Uspešno</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="389"/>
+        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit Boot Repair?&lt;/b&gt;</source>
+        <translation>Postopek je bil uspešno zaključen. &lt;p&gt;&lt;b&gt;Bi radi zaupstili Popravilo zagona?&lt;/b&gt;</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="395"/>
+        <source>Process finished. Errors have occurred.</source>
+        <translation>Postopek je končan. Pojavile so se napake.</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="412"/>
+        <source>Enter password to unlock %1 encrypted partition:</source>
+        <translation>Vnesite geslo za odklep šifriranega razdelka %1:</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="420"/>
+        <source>Sorry, could not open %1 LUKS container</source>
+        <translation>Oprostite, LUKS zabojnika %1 ni bilo mogoče odpreti</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="495"/>
         <source>Select GRUB location</source>
         <translation>Določi lokacijo za GRUB</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="398"/>
+        <location filename="mainwindow.cpp" line="507"/>
         <source>Select Item to Back Up</source>
-        <translation>Izberi kaj naj se varnostno kopira</translation>
+        <translation>Izberite predmet za varnostno kopiranje</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="405"/>
+        <location filename="mainwindow.cpp" line="514"/>
         <source>Select Item to Restore</source>
-        <translation>Izberite, kaj naj se obnovi</translation>
+        <translation>Izberite predmet, ki naj se obnovi</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="416"/>
+        <location filename="mainwindow.cpp" line="525"/>
         <source>Select backup file name</source>
         <translation>Določite ime varostne kopije</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="418"/>
-        <location filename="bootrepair.cpp" line="425"/>
+        <location filename="mainwindow.cpp" line="527"/>
+        <location filename="mainwindow.cpp" line="534"/>
         <source>No file was selected.</source>
         <translation>Nobena datoteka ni bila izbrana.</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="423"/>
+        <location filename="mainwindow.cpp" line="532"/>
         <source>Select MBR or PBR backup file</source>
         <translation>Izberite MBR ali PBR varnostno kopijo</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="444"/>
-        <source>About Boot Repair</source>
-        <translation>O Popravilu zagona</translation>
+        <location filename="mainwindow.cpp" line="552"/>
+        <source>About %1</source>
+        <translation>O %1</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="445"/>
+        <location filename="mainwindow.cpp" line="553"/>
         <source>Version: </source>
         <translation>Različica:</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="447"/>
+        <location filename="mainwindow.cpp" line="554"/>
         <source>Simple boot repair program for antiX Linux</source>
         <translation>Preprost program za popravilo zagona za antiX Linux</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="448"/>
+        <location filename="mainwindow.cpp" line="556"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="449"/>
+        <location filename="mainwindow.cpp" line="557"/>
+        <source>%1 License</source>
+        <translation>%1 licenca</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="571"/>
+        <source>%1 Help</source>
+        <translation>%1 pomoč</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="598"/>
+        <source>Sorry, could not mount %1 partition</source>
+        <translation>Oprostite, razdelka %1 ni bilo mogoče priklopiti</translation>
+    </message>
+</context>
+<context>
+    <name>QApplication</name>
+    <message>
+        <location filename="about.cpp" line="32"/>
         <source>License</source>
         <translation>Licenca</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="452"/>
-        <source>&apos;Boot Repair License&apos;</source>
-        <translation>&apos;Popravilo zagona licenca&apos;</translation>
+        <location filename="about.cpp" line="33"/>
+        <location filename="about.cpp" line="43"/>
+        <source>Changelog</source>
+        <translation>Dnevnik sprememb</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="461"/>
-        <source>&apos;Boot Repair Help&apos;</source>
-        <translation>&apos;Popravilo zagona pomoč&apos;</translation>
+        <location filename="about.cpp" line="34"/>
+        <source>Cancel</source>
+        <translation>Prekliči</translation>
     </message>
     <message>
-        <location filename="ui_bootrepair.h" line="390"/>
-        <source>Boot Repair is a utility that can be used to reinstall GRUB bootloader on the MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR.</source>
-        <translation>Popravljanje zagona je orodje za ponovno namestitev GRUB zaganjalnika na MBR (Master Boot Record) ali korensko tj. root razdelek. Ponuja možnost rekonstrukcije GRUB konfiguracijske datoteke in ustvarjanja varnostne kopije MBR ali PBR ali obnovo iz le-te.</translation>
+        <location filename="about.cpp" line="51"/>
+        <source>&amp;Close</source>
+        <translation>&amp;Zapri</translation>
     </message>
     <message>
-        <location filename="ui_bootrepair.h" line="393"/>
-        <source>Reinstall GRUB bootloader</source>
-        <translation>Ponovno namesti GRUB zaganjalnik</translation>
+        <location filename="main.cpp" line="64"/>
+        <source>You must run this program as root.</source>
+        <translation>Ta program morate zagnati kot root</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
